command = xplor.command
from jCoupPot import JCoupPot 
from noePot import NOEPot

import prePot

from xplor import select

from xplorPot import XplorPot
from rdcPotTools import *
from pdbTool import *
from atomAction import *
from selectTools import *
from simulationTools import *
from ivm import IVM

import protocol
import monteCarlo

protocol.initRandomSeed()

protocol.initParams('./parallhdg_new.pro')

protocol.initStruct('./qbp.psf')

protocol.initCoords('1gggH.pdb')

AtomSel("resi 87:184").apply( SetProperty('segmentName','ALT0') )

numT=2

for cnt in range(1,numT):
  seg="ALT%d" % cnt
  command("duplicate sele=(segid ALT0 and resi 87:184) segid=%s end" % seg)
  pass

protocol.initNBond(repel=1.2)

command("""

    constraints

    inter = (segid " ") (segid ALT1 and resi 90:180)

    inter = (segid ALT1 and (resi 87:89 or resi 181:184)) (segid ALT1 or segid " ")

    weights * 1 end end

    """)

#
# annealing settings
#

init_t  = 3000
final_t = 25

cool_steps = 12000

from simulationTools import MultRamp, StaticRamp, InitialParams
rampedParams=[]

potList = PotList()
potList.add( XplorPot("BOND") )

potList.add( XplorPot("ANGL") )
rampedParams.append( MultRamp(0.4,1,"potList['ANGL'].setScale(VALUE)") )

potList.add( XplorPot("IMPR") )
rampedParams.append( MultRamp(0.4,1,"potList['IMPR'].setScale(VALUE)") )

potList.add( XplorPot("VDW") )
rampedParams.append( MultRamp(1.2,0.8,
                              "command('param nbonds repel VALUE end end')") )
rampedParams.append( MultRamp(.004,4,
                              "command('param nbonds rcon VALUE end end')") )

from torsionDBPotTools import create_TorsionDBPot
torsionDBPot = create_TorsionDBPot('tDB', selection='(segid alt1 and (resi 84:92 or resi 178:187))')
potList.append( torsionDBPot )
rampedParams.append( MultRamp(.01,1,"torsionDBPot.setScale(VALUE)") )

noe=PotList('noe')
potList.append(noe)
from noePotTools import create_NOEPot

pot = create_NOEPot('cxms',"./noe_inter_1113.tbl")
pot.setPotType("hard")
pot.setScale(1)       
pot.setAveType("sum")
noe.append(pot)

rampedParams.append( MultRamp(1,100, "noe.setScale( VALUE )") )

# IVM setup
#

dyn  = IVM()

dyn.fix(""" segid ALT0 or segid " " """)

dyn.group("""segid ALT1 and resi 90:180 """)

dyn.breakAllBondsIn("""(resi  86 and name C) or (resi  87 and name N)""")
dyn.breakAllBondsIn("""(resi 184 and name C) or (resi 185 and name N)""")

protocol.updatePseudoAtoms()

dyn.autoTorsion()

def structLoopAction(loopInfo):

    protocol.initMinimize(dyn, potList=potList)
    potList["VDW"].setScale(0)
    InitialParams( rampedParams )
    dyn.run()
    dyn.run()

    #
    # high temp dynamics
    #

    ini_timestep = 0.010
    protocol.initDynamics(dyn,
                          potList=potList,
                          bathTemp=init_t,
                          initVelocities=True,
                          stepsize=ini_timestep,
                          finalTime=20,
                          printInterval=100)
    dyn.run()

    #
    # cooling
    #

    timestep=ini_timestep
    potList["VDW"].setScale(1)

    protocol.initDynamics(dyn,
                          potList=potList,
                          bathTemp=init_t,
                          initVelocities=True,
                          stepsize=timestep,
                          finalTime=0.5,
                          printInterval=100)

    dyn.setResetCMInterval( 100 )

    AnnealIVM(initTemp =init_t,
              finalTemp=final_t,
              numSteps = 50,
              ivm=dyn,
              rampedParams = rampedParams).run()
    #
    # final Powell minimization
    #
    protocol.initMinimize(dyn)
    dyn.run()

    loopInfo.writeStructure(potList)

    pass

StructureLoop(numStructures=256,
              pdbTemplate='./Output/QBP_2conf_fixed_STRUCTURE.pdb',
              averagePotList=potList,
              genViolationStats=1,
              structLoopAction=structLoopAction).run()
